@@ -4,7 +4,7 @@ from __future__ import annotations
 import logging
 from multiprocessing import cpu_count
 from typing import Sequence, Callable, Literal
-from .levels import CalibratedData, read_step, _ReductionStep
+from .levels import CalibratedData, read_step, _ReductionStep, RawData
 from . import types as tp
 import attr
 import h5py
@@ -483,9 +483,9 @@ def get_gha_model_filter(
     aggregator
         A specialized function that takes a file and some parameters and returns
         an aggregated metric.
-    metric_model_type
+    metric_model
         A linear model to be fit to the aggregated metric data.
-    std_model_type
+    std_model
         A linear model to be fit to the absolute residuals of the metric data.
     metric_model_kwargs
         Parameters for the linear model (such as ``n_terms``) to fit to the metric.
@@ -842,7 +842,7 @@ def time_filter_auxiliary(
     return flags
 
 
-@step_filter(axis="time", data_type=CalibratedData)
+@step_filter(axis="time", data_type=(RawData, CalibratedData))
 def aux_filter(
     *,
     data: CalibratedData,
@@ -991,7 +991,7 @@ def total_power_filter(
     return [np.any([f[iday] for f in flags], axis=0) for iday in range(len(flags[0]))]
 
 
-@step_filter(axis="time", data_type=CalibratedData)
+@step_filter(axis="time", data_type=(RawData, CalibratedData))
 def negative_power_filter(*, data: CalibratedData):
     """Filter out integrations that have *any* negative/zero power.
 
